@@ -58,6 +58,48 @@ FAKE_RESPONSE_HEADERS = {'x-openstack-request-id': FAKE_REQUEST_ID}
 FAKE_SERVICE_UUID_1 = '75e9eabc-ed3b-4f11-8bba-add1e7e7e2de'
 FAKE_SERVICE_UUID_2 = '1f140183-c914-4ddf-8757-6df73028aa86'
 
+SERVER_TOPOLOGY = {
+    "nodes": [
+        {
+            "cpu_pinning": {
+                "0": 0,
+                "1": 5
+            },
+            "host_node": 0,
+            "memory_mb": 1024,
+            "siblings": [
+                [
+                    0,
+                    1
+                ]
+            ],
+            "vcpu_set": [
+                0,
+                1
+            ]
+        },
+        {
+            "cpu_pinning": {
+                "2": 1,
+                "3": 8
+            },
+            "host_node": 1,
+            "memory_mb": 2048,
+            "siblings": [
+                [
+                    2,
+                    3
+                ]
+            ],
+            "vcpu_set": [
+                2,
+                3
+            ]
+        }
+    ],
+    "pagesize_kb": 4
+}
+
 
 class FakeClient(fakes.FakeClient, client.Client):
 
@@ -286,53 +328,6 @@ class FakeSessionClient(base_client.SessionClient):
                       "md5hash": "add6bb58e139be103324d04d82d8f546",
                       'id': 1}})
 
-    #
-    # List all extensions
-    #
-
-    def get_extensions(self, **kw):
-        exts = [
-            {
-                "alias": "NMN",
-                "description": "Multiple network support",
-                "links": [],
-                "name": "Multinic",
-                "namespace": ("http://docs.openstack.org/"
-                              "compute/ext/multinic/api/v1.1"),
-                "updated": "2011-06-09T00:00:00+00:00"
-            },
-            {
-                "alias": "OS-DCF",
-                "description": "Disk Management Extension",
-                "links": [],
-                "name": "DiskConfig",
-                "namespace": ("http://docs.openstack.org/"
-                              "compute/ext/disk_config/api/v1.1"),
-                "updated": "2011-09-27T00:00:00+00:00"
-            },
-            {
-                "alias": "OS-EXT-SRV-ATTR",
-                "description": "Extended Server Attributes support.",
-                "links": [],
-                "name": "ExtendedServerAttributes",
-                "namespace": ("http://docs.openstack.org/"
-                              "compute/ext/extended_status/api/v1.1"),
-                "updated": "2011-11-03T00:00:00+00:00"
-            },
-            {
-                "alias": "OS-EXT-STS",
-                "description": "Extended Status support",
-                "links": [],
-                "name": "ExtendedStatus",
-                "namespace": ("http://docs.openstack.org/"
-                              "compute/ext/extended_status/api/v1.1"),
-                "updated": "2011-11-03T00:00:00+00:00"
-            },
-        ]
-        return (200, FAKE_RESPONSE_HEADERS, {
-            "extensions": exts,
-        })
-
     #
     # Limits
     #
@@ -738,6 +733,9 @@ class FakeSessionClient(base_client.SessionClient):
                 'rules': []}]
         })
 
+    def get_servers_1234_topology(self, **kw):
+        return 200, {}, SERVER_TOPOLOGY
+
     #
     # Server password
     #
@@ -1143,7 +1141,7 @@ class FakeSessionClient(base_client.SessionClient):
     # Images
     #
     def get_images(self, **kw):
-        return (200, {}, {'images': [
+        images = [
             {
                 "id": FAKE_IMAGE_UUID_SNAPSHOT,
                 "name": "My Server Backup",
@@ -1193,7 +1191,16 @@ class FakeSessionClient(base_client.SessionClient):
                 "progress": 80,
                 "links": {},
             },
-        ]})
+        ]
+
+        if 'id' in kw:
+            requested = kw['id'].replace('in:', '').split(',')
+            images = [i for i in images if i['id'] in requested]
+        if 'names' in kw:
+            requested = kw['names'].replace('in:', '').split(',')
+            images = [i for i in images if i['name'] in requested]
+
+        return (200, {}, {'images': images})
 
     def get_images_555cae93_fb41_4145_9c52_f5b923538a26(self, **kw):
         return (200, {}, {'image': self.get_images()[2]['images'][0]})
@@ -1727,6 +1734,9 @@ class FakeSessionClient(base_client.SessionClient):
     def delete_os_aggregates_1(self, **kw):
         return (202, {}, None)
 
+    def post_os_aggregates_1_images(self, body, **kw):
+        return (202, {}, None)
+
     #
     # Services
     #
@@ -2070,6 +2080,11 @@ class FakeSessionClient(base_client.SessionClient):
         if self.api_version >= api_versions.APIVersion('2.70'):
             # Include the "tag" field in the response.
             attachment['tag'] = 'test-tag'
+
+        if self.api_version >= api_versions.APIVersion('2.79'):
+            # Include the "delete_on_termination" field in the
+            # response.
+            attachment['delete_on_termination'] = True
         return (200, FAKE_RESPONSE_HEADERS, {"volumeAttachment": attachment})
 
     def put_servers_1234_os_volume_attachments_Work(self, **kw):
@@ -2094,6 +2109,12 @@ class FakeSessionClient(base_client.SessionClient):
             # Include the "tag" field in each attachment.
             for attachment in attachments['volumeAttachments']:
                 attachment['tag'] = 'test-tag'
+
+        if self.api_version >= api_versions.APIVersion('2.79'):
+            # Include the "delete_on_termination" field in each
+            # attachment.
+            for attachment in attachments['volumeAttachments']:
+                attachment['delete_on_termination'] = True
         return (200, FAKE_RESPONSE_HEADERS, attachments)
 
     def get_servers_1234_os_volume_attachments_Work(self, **kw):
@@ -2240,34 +2261,6 @@ class FakeSessionClient(base_client.SessionClient):
     def post_servers_uuid6_action(self, **kw):
         return 202, {}, {}
 
-    def get_os_cells_child_cell(self, **kw):
-        cell = {'cell': {
-            'username': 'cell1_user',
-            'name': 'cell1',
-            'rpc_host': '10.0.1.10',
-            'info': {
-                'username': 'cell1_user',
-                'rpc_host': '10.0.1.10',
-                'type': 'child',
-                'name': 'cell1',
-                'rpc_port': 5673},
-            'type': 'child',
-            'rpc_port': 5673,
-            'loaded': True
-        }}
-        return (200, FAKE_RESPONSE_HEADERS, cell)
-
-    def get_os_cells_capacities(self, **kw):
-        cell_capacities_response = {"cell": {"capacities": {"ram_free": {
-            "units_by_mb": {"8192": 0, "512": 13, "4096": 1, "2048": 3,
-                            "16384": 0}, "total_mb": 7680}, "disk_free": {
-            "units_by_mb": {"81920": 11, "20480": 46, "40960": 23, "163840": 5,
-                            "0": 0}, "total_mb": 1052672}}}}
-        return (200, FAKE_RESPONSE_HEADERS, cell_capacities_response)
-
-    def get_os_cells_child_cell_capacities(self, **kw):
-        return self.get_os_cells_capacities()
-
     def get_os_migrations(self, **kw):
         migration1 = {
             "created_at": "2012-10-29T13:42:02.000000",
@@ -2307,6 +2300,14 @@ class FakeSessionClient(base_client.SessionClient):
             migration1.update({"uuid": "11111111-07d5-11e1-90e3-e3dffe0c5983"})
             migration2.update({"uuid": "22222222-07d5-11e1-90e3-e3dffe0c5983"})
 
+        if self.api_version >= api_versions.APIVersion("2.80"):
+            migration1.update({
+                "project_id": "b59c18e5fa284fd384987c5cb25a1853",
+                "user_id": "13cc0930d27c4be0acc14d7c47a3e1f7"})
+            migration2.update({
+                "project_id": "b59c18e5fa284fd384987c5cb25a1853",
+                "user_id": "13cc0930d27c4be0acc14d7c47a3e1f7"})
+
         migration_list = []
         instance_uuid = kw.get('instance_uuid', None)
         if instance_uuid == migration1['instance_uuid']:
@@ -2398,6 +2399,12 @@ class FakeSessionClient(base_client.SessionClient):
             "disk_remaining_bytes": 230000,
             "updated_at": "2016-01-29T13:42:02.000000"
         }}
+
+        if self.api_version >= api_versions.APIVersion("2.80"):
+            migration['migration'].update({
+                "project_id": "b59c18e5fa284fd384987c5cb25a1853",
+                "user_id": "13cc0930d27c4be0acc14d7c47a3e1f7"})
+
         return (200, FAKE_RESPONSE_HEADERS, migration)
 
     @api_versions.wraps(start_version="2.23")
@@ -2421,6 +2428,12 @@ class FakeSessionClient(base_client.SessionClient):
                 "disk_remaining_bytes": 230000,
                 "updated_at": "2016-01-29T13:42:02.000000"
             }]}
+
+        if self.api_version >= api_versions.APIVersion("2.80"):
+            migrations['migrations'][0].update({
+                "project_id": "b59c18e5fa284fd384987c5cb25a1853",
+                "user_id": "13cc0930d27c4be0acc14d7c47a3e1f7"})
+
         return (200, FAKE_RESPONSE_HEADERS, migrations)
 
     def delete_servers_1234_migrations_1(self):
