@@ -24,7 +24,7 @@ from novaclient import base
 
 class Service(base.Resource):
     def __repr__(self):
-        return "<Service: %s>" % self.binary
+        return "<Service: %s>" % self.id
 
     def _add_details(self, info):
         dico = 'resource' in info and info['resource'] or info
@@ -70,27 +70,80 @@ class ServiceManager(base.ManagerWithFind):
             body["forced_down"] = force_down
         return body
 
+    @api_versions.wraps('2.0', '2.52')
     def enable(self, host, binary):
         """Enable the service specified by hostname and binary."""
         body = self._update_body(host, binary)
         return self._update("/os-services/enable", body, "service")
 
+    @api_versions.wraps('2.53')
+    def enable(self, service_uuid):
+        """Enable the service specified by the service UUID ID.
+
+        :param service_uuid: The UUID ID of the service to enable.
+        """
+        return self._update(
+            "/os-services/%s" % service_uuid, {'status': 'enabled'}, "service")
+
+    @api_versions.wraps('2.0', '2.52')
     def disable(self, host, binary):
         """Disable the service specified by hostname and binary."""
         body = self._update_body(host, binary)
         return self._update("/os-services/disable", body, "service")
 
+    @api_versions.wraps('2.53')
+    def disable(self, service_uuid):
+        """Disable the service specified by the service UUID ID.
+
+        :param service_uuid: The UUID ID of the service to disable.
+        """
+        return self._update("/os-services/%s" % service_uuid,
+                            {'status': 'disabled'}, "service")
+
+    @api_versions.wraps('2.0', '2.52')
     def disable_log_reason(self, host, binary, reason):
         """Disable the service with reason."""
         body = self._update_body(host, binary, reason)
         return self._update("/os-services/disable-log-reason", body, "service")
 
+    @api_versions.wraps('2.53')
+    def disable_log_reason(self, service_uuid, reason):
+        """Disable the service with a reason.
+
+        :param service_uuid: The UUID ID of the service to disable.
+        :param reason: The reason for disabling a service. The minimum length
+            is 1 and the maximum length is 255.
+        """
+        body = {
+            'status': 'disabled',
+            'disabled_reason': reason
+        }
+        return self._update("/os-services/%s" % service_uuid, body, "service")
+
     def delete(self, service_id):
-        """Delete a service."""
+        """Delete a service.
+
+        :param service_id: Before microversion 2.53, this must be an integer id
+            and may not uniquely the service in a multi-cell deployment.
+            Starting with microversion 2.53 this must be a UUID.
+        """
         return self._delete("/os-services/%s" % service_id)
 
-    @api_versions.wraps("2.11")
+    @api_versions.wraps("2.11", "2.52")
     def force_down(self, host, binary, force_down=None):
         """Force service state to down specified by hostname and binary."""
         body = self._update_body(host, binary, force_down=force_down)
         return self._update("/os-services/force-down", body, "service")
+
+    @api_versions.wraps("2.53")
+    def force_down(self, service_uuid, force_down):
+        """Update the service's ``forced_down`` field specified by the
+        service UUID ID.
+
+        :param service_uuid: The UUID ID of the service.
+        :param force_down: Whether or not this service was forced down manually
+            by an administrator. This value is useful to know that some 3rd
+            party has verified the service should be marked down.
+        """
+        return self._update("/os-services/%s" % service_uuid,
+                            {'forced_down': force_down}, "service")
